(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     44631,       1853]*)
(*NotebookOutlinePosition[     45385,       1880]*)
(*  CellTagsIndexPosition[     45341,       1876]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions for Thesis", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  PageWidth->WindowWidth,
  ScriptMinSize->9],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ScriptMinSize->5,
  FontSize->11,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],

Cell[StyleData["Notebook"],
  PageWidth->WindowWidth,
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, None}, {
      None, None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  PrintingOptions->{"PrintingMargins"->{{99, 99}, {108, 108}},
  "FirstPageHeader"->False,
  "FacingPages"->True},
  CellFrameLabelMargins->6,
  DefaultNewCellStyle->"Text",
  ShowAutoStyles->False,
  AutoItalicWords->{},
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Book Specific Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellMargins->{{55, 25}, {40, 10}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  TextAlignment->Center,
  CounterIncrements->"Title",
  CounterAssignments->{{"Chapter", 0}, {"Section", 0}, {"Equation", 0}, {
      "Figure", 0}, {"Subtitle", 0}, {"Example", 0}},
  FontFamily->"Times",
  FontSize->48],

Cell[StyleData["Title", "Printout"],
  FontSize->40]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellMargins->{{55, 25}, {2, 30}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}},
  FontFamily->"Times",
  FontSize->24,
  FontSlant->"Italic",
  FontColor->RGBColor[0.771908, 0.399634, 0.262867]],

Cell[StyleData["Subtitle", "Printout"],
  FontSize->18,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Chapter"],
  CellMargins->{{55, 25}, {80, 25}},
  CellGroupingRules->{"SectionGrouping", 0},
  PageBreakAbove->True,
  CounterIncrements->"Chapter",
  CounterAssignments->{{"Section", 0}, {"Theorem", 0}, {"InferenceRule", 0}, {
      "Definition", 0}, {"Equation", 0}, {"Figure", 0}, {"Example", 0}},
  FontFamily->"Times",
  FontSize->28,
  Background->RGBColor[0.771908, 0.399634, 0.262867]],

Cell[StyleData["Chapter", "Printout"],
  CellMargins->{{13, 0}, {40, 80}},
  FontSize->24,
  FontWeight->"Bold",
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellDingbat->None,
  CellMargins->{{25, Inherited}, {8, 24}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Times",
  FontSize->16,
  FontWeight->"Bold"],

Cell[StyleData["Section", "Printout"],
  CellMargins->{{13, 0}, {7, 22}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellDingbat->None,
  CellMargins->{{22, Inherited}, {8, 20}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Times",
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["Subsection", "Printout"],
  CellMargins->{{9, 0}, {7, 18}},
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellDingbat->None,
  CellMargins->{{22, Inherited}, {8, 18}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  CounterIncrements->"Subsubsection",
  FontFamily->"Times",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["Subsubsection", "Printout"],
  CellMargins->{{9, 0}, {7, 14}},
  FontSize->11]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Automatic Numbering", "Section"],

Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["NumberedEquation"],
  CellMargins->{{50, 10}, {7, 7}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "Chapter"], ".", 
            CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  CounterIncrements->"NumberedEquation",
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedEquation", "Printout"],
  CellMargins->{{39, 10}, {4, 9}}],

Cell[StyleData["NumberedEquation", "EnhancedPrintout"],
  CellMargins->{{55, 55}, {0, 10}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{12, 10}, {7, 7}},
  TextJustification->1,
  LineSpacing->{1, 3},
  CounterIncrements->"Text",
  FontFamily->"Times"],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{2, 0}, {6, 6}}],

Cell[StyleData["Text", "EnhancedPrintout"],
  CellMargins->{{2, 2}, {6, 6}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SmallText"],
  CellMargins->{{12, 10}, {6, 6}},
  LineSpacing->{1, 3},
  CounterIncrements->"SmallText",
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["SmallText", "Printout"],
  CellMargins->{{2, 2}, {5, 5}},
  FontSize->7]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text",
  FontSize->10],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellFrame->{{3, 0}, {0, 0}},
  CellMargins->{{50, 50}, {0, 0}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->Automatic,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  CellFrameColor->RGBColor[0.8, 0.8, 0.4],
  DefaultFormatType->DefaultInputFormatType,
  ParagraphSpacing->{1, 2},
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  Background->RGBColor[0.95021, 0.934356, 0.499062],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[StyleData["Input", "Printout"],
  CellFrame->False,
  CellMargins->{{13, 10}, {5, 5}},
  FontSize->10,
  Background->GrayLevel[0.8]],

Cell[StyleData["Input", "EnhancedPrintout"],
  CellMargins->{{39, 0}, {4, 6}},
  FontFamily->"WRICourier"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellFrame->{{3, 0}, {0, 0}},
  CellMargins->{{50, 50}, {15, 0}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  CellFrameColor->RGBColor[0.620523, 0.66688, 0.409964],
  DefaultFormatType->DefaultOutputFormatType,
  ParagraphSpacing->{1, 2},
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Output",
  Background->RGBColor[0.820523, 0.86688, 0.609964]],

Cell[StyleData["Output", "Printout"],
  CellFrame->False,
  CellMargins->{{13, 10}, {5, 5}},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["Output", "EnhancedPrintout"],
  CellMargins->{{39, 0}, {6, 4}},
  FontFamily->"WRICourier"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Message",
  StyleMenuListing->None,
  FontSize->10,
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Message", "Printout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontColor->GrayLevel[0]],

Cell[StyleData["Message", "EnhancedPrintout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontFamily->"WRICourier",
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellMargins->{{75, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Print",
  StyleMenuListing->None,
  FontSize->10],

Cell[StyleData["Print", "Printout"],
  CellMargins->{{57, Inherited}, {Inherited, Inherited}}],

Cell[StyleData["Print", "EnhancedPrintout"],
  CellMargins->{{57, Inherited}, {Inherited, Inherited}},
  FontFamily->"WRICourier"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellMargins->{{47, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  StyleMenuListing->None,
  FontSize->10],

Cell[StyleData["Graphics", "Printout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  ImageSize->{250, 250}],

Cell[StyleData["Graphics", "EnhancedPrintout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  ImageSize->{250, 250},
  FontFamily->"WRICourier"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["CellLabel", "Printout"],
  FontFamily->"Courier",
  FontSlant->"Italic",
  FontColor->GrayLevel[0]],

Cell[StyleData["CellLabel", "EnhancedPrintout"],
  FontFamily->"WRICourier",
  FontSlant->"Italic",
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Theorem Like Structures", "Section",
  TextJustification->1],

Cell[CellGroupData[{

Cell[StyleData["Definition"],
  CellMargins->{{12, 10}, {7, 7}},
  TextJustification->1,
  LineSpacing->{1, 3},
  CounterIncrements->"Definition"],

Cell[StyleData["Definition", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Lemma"],
  CellMargins->{{12, 10}, {7, 7}},
  TextJustification->1,
  LineSpacing->{1, 3},
  CounterIncrements->"Lemma"],

Cell[StyleData["Lemma", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Theorem"],
  CellMargins->{{12, 10}, {7, 7}},
  TextJustification->1,
  LineSpacing->{1, 3},
  CounterIncrements->"Theorem"],

Cell[StyleData["Theorem", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["InferenceRule"],
  CellMargins->{{12, 10}, {7, 7}},
  TextJustification->1,
  LineSpacing->{1, 3},
  CounterIncrements->"InferenceRule"],

Cell[StyleData["InferenceRule", "Printout"],
  CellMargins->{{2, 0}, {6, 10}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ProofBegin"],
  CellMargins->{{12, 10}, {7, 7}},
  TextJustification->1,
  LineSpacing->{1, 3}],

Cell[StyleData["ProofBegin", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Example"],
  CellMargins->{{12, 10}, {7, 7}},
  TextJustification->1,
  LineSpacing->{1, 3},
  CounterIncrements->"Example"],

Cell[StyleData["Example", "Printout"],
  CellMargins->{{2, 0}, {6, 10}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Figure"],
  CellMargins->{{50, 4}, {0, 2}},
  PageBreakAbove->False,
  TextJustification->1,
  CounterIncrements->"Figure",
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["Figure", "Printout"],
  CellMargins->{{50, 4}, {2, 4}},
  FontSize->7]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Remark"],
  CellMargins->{{12, 10}, {7, 7}},
  TextJustification->1,
  LineSpacing->{1, 3},
  CounterIncrements->"Remark"],

Cell[StyleData["Remark", "Printout"],
  CellMargins->{{2, 0}, {6, 10}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Paragraph"],
  CellMargins->{{12, 10}, {7, 14}},
  TextJustification->1,
  LineSpacing->{1, 3},
  CounterIncrements->"Paragraph"],

Cell[StyleData["Paragraph", "Printout"],
  CellMargins->{{2, 0}, {6, 12}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Miscellaneous Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["MathCaption"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{45, 62}, {0, 14}},
  LineSpacing->{1, 1},
  ParagraphSpacing->{0, 8},
  FontColor->RGBColor[0, 0, 0.6]],

Cell[StyleData["MathCaption", "Printout"],
  CellMargins->{{39, 62}, {0, 14}},
  FontColor->GrayLevel[0]],

Cell[StyleData["MathCaption", "EnhancedPrintout"],
  CellMargins->{{39, 62}, {0, 14}},
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Commentary"],
  CellFrame->{{2, 0}, {0, 0}},
  CellMargins->{{35, 10}, {7, 7}},
  CellFrameMargins->8,
  CellFrameColor->RGBColor[0, 0.2, 1],
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 8},
  FontSlant->"Italic"],

Cell[StyleData["Commentary", "Printout"],
  CellMargins->{{29, 0}, {6, 6}},
  FontSize->10],

Cell[StyleData["Commentary", "EnhancedPrintout"],
  CellMargins->{{29, 0}, {6, 6}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemizedText"],
  CellMargins->{{40, 10}, {0, 8}},
  TextJustification->1,
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 4},
  ParagraphIndent->-21,
  CounterIncrements->"ItemizedText"],

Cell[StyleData["ItemizedText", "Printout"],
  CellMargins->{{28, 4}, {0, 8}},
  ParagraphIndent->-9],

Cell[StyleData["ItemizedText", "EnhancedPrintout"],
  ParagraphIndent->-13,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemizedText1"],
  CellMargins->{{70, 10}, {0, 7}},
  TextJustification->1,
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 4},
  ParagraphIndent->-21,
  CounterIncrements->"ItemizedText1"],

Cell[StyleData["ItemizedText1", "Printout"],
  CellMargins->{{58, 4}, {0, 7}},
  ParagraphIndent->-7],

Cell[StyleData["ItemizedText1", "EnhancedPrintout"],
  ParagraphIndent->-13,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemizedTextNote"],
  CellMargins->{{35, 4}, {0, 4}},
  ShowSpecialCharacters->Automatic,
  ParagraphSpacing->{0, 4},
  CounterIncrements->"Text"],

Cell[StyleData["ItemizedTextNote", "Printout"],
  CellMargins->{{33, Inherited}, {Inherited, Inherited}}],

Cell[StyleData["ItemizedTextNote", "EnhancedPrintout"],
  CellMargins->{{33, Inherited}, {Inherited, Inherited}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["BulletText"],
  CellMargins->{{40, 10}, {0, 4}},
  TextJustification->1,
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 4},
  ParagraphIndent->-14],

Cell[StyleData["BulletText", "Printout"],
  CellMargins->{{28, 4}, {0, 4}},
  ParagraphIndent->-9],

Cell[StyleData["BulletText", "EnhancedPrintout"],
  ParagraphIndent->-18,
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["BulletText", "EnhancedPrintoutNonGray"],
  ParagraphIndent->-18,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["BulletText1"],
  CellMargins->{{70, 10}, {0, 3}},
  TextJustification->1,
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 4},
  ParagraphIndent->-14],

Cell[StyleData["BulletText1", "Printout"],
  CellMargins->{{58, 4}, {0, 3}},
  ParagraphIndent->-9],

Cell[StyleData["BulletText1", "EnhancedPrintout"],
  ParagraphIndent->-18,
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["BulletText1", "EnhancedPrintoutNonGray"],
  ParagraphIndent->-18,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["BItem1"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{51, 10}, {0, 4}},
  TextJustification->1,
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 4},
  ParagraphIndent->-1],

Cell[StyleData["BItem1", "Printout"],
  CellMargins->{{37.5, 2}, {2, 2}}],

Cell[StyleData["BItem1", "EnhancedPrintout"],
  ParagraphIndent->-18,
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["BItem1", "EnhancedPrintoutNonGray"],
  ParagraphIndent->-18,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["NItem1"],
  CellMargins->{{36, 10}, {0, 4}},
  CellFrameLabels->{{Cell[ 
          TextData[ {
            CounterBox[ "NItem1"], "."}]], None}, {None, None}},
  CellFrameLabelMargins->{{-1, 0}, {-1, 0}},
  TextJustification->1,
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 4},
  ParagraphIndent->-1,
  CounterIncrements->"NItem1"],

Cell[StyleData["NItem1", "Printout"],
  CellMargins->{{22, 4}, {0, 4}}],

Cell[StyleData["NItem1", "EnhancedPrintout"],
  ParagraphIndent->-18,
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["NItem1", "EnhancedPrintoutNonGray"],
  ParagraphIndent->-18,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ContinueBItem1"],
  CellMargins->{{51, 10}, {4, 0}},
  TextJustification->1,
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 4},
  ParagraphIndent->-1],

Cell[StyleData["ContinueBItem1", "Printout"],
  CellMargins->{{37.5, 2}, {2, 2}}],

Cell[StyleData["ContinueBItem1", "EnhancedPrintout"],
  ParagraphIndent->-18,
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["ContinueBItem1", "EnhancedPrintoutNonGray"],
  ParagraphIndent->-18,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["BItem2"],
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{81, 10}, {0, 4}},
  TextJustification->1,
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 4},
  ParagraphIndent->-1],

Cell[StyleData["BItem2", "Printout"],
  CellMargins->{{67.75, 2}, {2, 2}}],

Cell[StyleData["BItem2", "EnhancedPrintout"],
  ParagraphIndent->-18,
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["BItem2", "EnhancedPrintoutNonGray"],
  ParagraphIndent->-18,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["NItem2"],
  CellMargins->{{57, 10}, {0, 4}},
  CellFrameLabels->{{Cell[ 
          TextData[ {
            CounterBox[ "NItem1"], ".", 
            CounterBox[ "NItem2"], "."}]], None}, {None, None}},
  TextJustification->1,
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 4},
  ParagraphIndent->-1,
  CounterIncrements->"NItem2"],

Cell[StyleData["NItem2", "Printout"],
  CellMargins->{{43, 4}, {0, 4}}],

Cell[StyleData["NItem2", "EnhancedPrintout"],
  ParagraphIndent->-18,
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["NItem2", "EnhancedPrintoutNonGray"],
  ParagraphIndent->-18,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IndentedText"],
  CellMargins->{{28, 10}, {0, 6}},
  ShowSpecialCharacters->Automatic,
  ParagraphSpacing->{0, 8},
  CounterIncrements->"Text"],

Cell[StyleData["IndentedText", "Printout"]],

Cell[StyleData["IndentedText", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Picture"],
  CellMargins->{{10, Inherited}, {0, 8}},
  CellHorizontalScrolling->True],

Cell[StyleData["Picture", "Printout"],
  CellMargins->{{2, Inherited}, {0, 8}}],

Cell[StyleData["Picture", "EnhancedPrintout"],
  CellMargins->{{2, Inherited}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Caption"],
  CellMargins->{{10, 50}, {2, 2}},
  PageBreakAbove->False,
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["Caption", "Printout"],
  CellMargins->{{10, 50}, {2, 2}},
  FontSize->7],

Cell[StyleData["Caption", "EnhancedPrintout"],
  CellMargins->{{10, 50}, {2, 2}},
  FontFamily->"Futura",
  FontSize->7]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Reference"],
  CellMargins->{{12, 10}, {7, 7}},
  LineSpacing->{1, 3},
  ParagraphIndent->-30,
  CounterIncrements->"Reference"],

Cell[StyleData["Reference", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formulas and Programming", "Section"],

Cell[CellGroupData[{

Cell[StyleData["DisplayFormula"],
  CellMargins->{{50, 10}, {7, 7}},
  CellHorizontalScrolling->True,
  ScriptLevel->0,
  SingleLetterItalics->True,
  StyleMenuListing->None,
  UnderoverscriptBoxOptions->{LimitsPositioning->True}],

Cell[StyleData["DisplayFormula", "Printout"],
  CellMargins->{{39, 10}, {4, 9}}],

Cell[StyleData["DisplayFormula", "EnhancedPrintout"],
  FontFamily->"Palatino"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Program"],
  CellFrame->{{0, 0}, {0.5, 0.5}},
  CellMargins->{{50, 50}, {Inherited, Inherited}},
  CellFrameMargins->{{0, 0}, {7, 5}},
  AutoSpacing->False],

Cell[StyleData["Program", "Printout"],
  CellMargins->{{28, 28}, {Inherited, 4}}],

Cell[StyleData["Program", "EnhancedPrintout"],
  CellMargins->{{18, 30}, {Inherited, 4}},
  FontFamily->"WRICourier",
  FontSize->9.5]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Boxes", "Section"],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}}],

Cell[StyleData["DefinitionBox", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10],

Cell[StyleData["DefinitionBox", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GrayBox"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {2, 8}},
  CellHorizontalScrolling->True,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  Background->GrayLevel[0.8],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnAlignments->{Left}}],

Cell[StyleData["GrayBox", "Printout"],
  CellMargins->{{2, 0}, {2, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["GrayBox", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Table"],
  CellMargins->{{10, 4}, {2, 8}},
  CellHorizontalScrolling->True,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  FontFamily->"Times",
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnAlignments->{Left}}],

Cell[StyleData["Table", "Printout"],
  CellMargins->{{2, 0}, {2, 8}},
  FontSize->10],

Cell[StyleData["Table", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["2ColumnTable1"],
  CellMargins->{{7, 7}, {2, 8}},
  CellHorizontalScrolling->False,
  AutoIndent->False,
  AutoSpacing->True,
  LineIndent->0,
  FontFamily->"Times",
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.2, 0.8},
  RowAlignments->Top,
  ColumnAlignments->{Right, Left},
  GridFrame->False,
  RowLines->False,
  ColumnLines->False,
  ColumnsEqual->False}],

Cell[StyleData["2ColumnTable1", "Printout"],
  CellMargins->{{2, 0}, {2, 8}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["2ColumnTable"],
  CellMargins->{{10, 7}, {2, 8}},
  CellHorizontalScrolling->True,
  AutoIndent->False,
  AutoSpacing->True,
  LineIndent->0,
  FontFamily->"Times",
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  RowAlignments->Top,
  ColumnAlignments->{Left},
  GridFrame->True,
  RowLines->True,
  ColumnLines->True,
  ColumnsEqual->False}],

Cell[StyleData["2ColumnTable", "Printout"],
  CellMargins->{{2, 0}, {2, 8}},
  FontSize->10],

Cell[StyleData["2ColumnTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["3ColumnTable"],
  CellMargins->{{30, 4}, {2, 8}},
  CellHorizontalScrolling->True,
  AutoIndent->False,
  TextAlignment->Left,
  AutoSpacing->True,
  LineIndent->0,
  FontFamily->"Times",
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->Automatic,
  RowAlignments->Center,
  ColumnAlignments->{Left, Center},
  GridFrame->True,
  RowLines->True,
  ColumnLines->True}],

Cell[StyleData["3ColumnTable", "Printout"],
  CellMargins->{{2, 0}, {2, 8}},
  FontSize->10],

Cell[StyleData["3ColumnTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Proof Cells", "Section",
  FontSize->10],

Cell[CellGroupData[{

Cell[StyleData["Label"],
  CellMargins->{{20, 30}, {7, 7}},
  CellGroupingRules->"OutputGrouping",
  LineSpacing->{1, -1},
  StyleMenuListing->None,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Label", "Printout"],
  CellMargins->{{2, 2}, {6, 6}},
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Conclusion"],
  CellMargins->{{12, 10}, {7, 7}},
  CellGroupingRules->"OutputGrouping",
  LineSpacing->{1, -1},
  StyleMenuListing->None,
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Conclusion", "Printout"],
  CellMargins->{{2, 2}, {6, 6}},
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Assumption"],
  CellMargins->{{12, 10}, {7, 7}},
  CellGroupingRules->"OutputGrouping",
  LineSpacing->{1, -1},
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0, 1]],

Cell[StyleData["Assumption", "Printout"],
  CellMargins->{{2, 2}, {6, 6}},
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Expression"],
  CellMargins->{{50, 50}, {7, 7}},
  CellGroupingRules->"OutputGrouping",
  LineSpacing->{1, -1},
  StyleMenuListing->None,
  FontSlant->"Italic",
  UnderoverscriptBoxOptions->{LimitsPositioning->True}],

Cell[StyleData["Expression", "Printout"],
  CellMargins->{{39, 10}, {6, 6}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TmaText"],
  CellMargins->{{25, 50}, {7, 7}},
  CellGroupingRules->"OutputGrouping",
  LineSpacing->{1, 1},
  StyleMenuListing->None,
  FontSlant->"Italic",
  UnderoverscriptBoxOptions->{LimitsPositioning->True}],

Cell[StyleData["TmaText", "Printout"],
  CellMargins->{{12, 5}, {6, 6}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Indent"],
  CellSize->{25, Inherited},
  StyleMenuListing->None,
  FontSize->10,
  FontSlant->"Italic"],

Cell[StyleData["Indent", "Printout"],
  CellSize->{15, Inherited}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Blank"],
  CellSize->{15, Inherited},
  StyleMenuListing->None,
  FontSize->10,
  FontSlant->"Italic"],

Cell[StyleData["Blank", "Printout"],
  CellSize->{10, Inherited}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inline Formatting", "Section"],

Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],

Cell[StyleData["RM"],
  StyleMenuListing->None,
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["BF"],
  StyleMenuListing->None,
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["IT"],
  StyleMenuListing->None,
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["BI"],
  StyleMenuListing->None,
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["TR"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["TI"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["TB"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["TBI"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["MR"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["MO"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["MB"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["MBO"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["SR"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["SO"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SB"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["SBO"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic"]
}, Closed]],

Cell[CellGroupData[{

Cell["Contents and Index", "Section"],

Cell[CellGroupData[{

Cell[StyleData["ContentsTitle"],
  ShowCellBracket->False,
  CellMargins->{{10, 4}, {0, 18}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->18,
  FontWeight->"Bold"],

Cell[StyleData["ContentsTitle", "Printout"],
  CellMargins->{{2, 0}, {0, 18}},
  PageBreakBelow->False,
  FontSize->18],

Cell[StyleData["ContentsTitle", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 18}},
  PageBreakBelow->False,
  FontFamily->"Futura",
  FontSize->18]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ContentsChapter"],
  ShowCellBracket->False,
  CellMargins->{{10, 4}, {3, 18}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["ContentsSection", "Printout"],
  CellMargins->{{2, 0}, {3, 18}},
  PageBreakBelow->False,
  FontSize->12],

Cell[StyleData["ContentsSection", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {3, 18}},
  PageBreakBelow->False,
  FontFamily->"Futura",
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ContentsSection"],
  ShowCellBracket->False,
  CellMargins->{{12, 4}, {3, 18}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["ContentsSection", "Printout"],
  CellMargins->{{2, 0}, {3, 18}},
  PageBreakBelow->False,
  FontSize->12],

Cell[StyleData["ContentsSection", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {3, 18}},
  PageBreakBelow->False,
  FontFamily->"Futura",
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Contents"],
  ShowCellBracket->False,
  CellMargins->{{12, 4}, {0, 8}},
  StyleMenuListing->None],

Cell[StyleData["Contents", "Printout"],
  CellMargins->{{2, 0}, {0, 8}}],

Cell[StyleData["Contents", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Index"],
  ShowCellBracket->False,
  CellMargins->{{21, 4}, {0, 0}},
  ParagraphIndent->-48,
  StyleMenuListing->None],

Cell[StyleData["Index", "Printout"],
  CellMargins->{{13, 0}, {0, 0}},
  FontSize->10],

Cell[StyleData["Index", "EnhancedPrintout"],
  CellMargins->{{13, 0}, {0, 0}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IndexSubentry"],
  ShowCellBracket->False,
  CellMargins->{{36, 4}, {0, 0}},
  ParagraphIndent->-48,
  StyleMenuListing->None],

Cell[StyleData["IndexSubentry", "Printout"],
  CellMargins->{{24, 0}, {0, 0}},
  FontSize->10],

Cell[StyleData["IndexSubentry", "EnhancedPrintout"],
  CellMargins->{{24, 0}, {0, 0}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section"],

Cell[StyleData["Header", "Printout"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->10,
  FontSlant->"Italic"],

Cell[StyleData["Header", "EnhancedPrintout"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Palatino",
  FontSize->10,
  FontSlant->"Italic"],

Cell[StyleData["Footer", "Printout"],
  CellMargins->{{0, 0}, {0, 4}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->7,
  FontSlant->"Plain"],

Cell[StyleData["Footer", "EnhancedPrintout"],
  CellMargins->{{0, 0}, {0, 4}},
  StyleMenuListing->None,
  FontFamily->"Futura",
  FontSize->8,
  FontSlant->"Plain"],

Cell[StyleData["PageNumber", "Printout"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->10,
  FontWeight->0],

Cell[StyleData["PageNumber", "EnhancedPrintout"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Futura",
  FontSize->10,
  FontWeight->"Bold"]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->False},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["Hyperlink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["MainBookLink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AddOnLink", "Printout"],
  FontFamily->"Courier",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["AddOnLink", "EnhancedPrintout"],
  FontFamily->"WRICourier",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["RefGuideLink", "EnhancedPrintout"],
  FontFamily->"WRICourier",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["GettingStartedLink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["OtherInformationLink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["System Styles", "Section"],

Cell[CellGroupData[{

Cell["Palette Styles", "Subsection"],

Cell["\<\
The cells below define styles that define standard ButtonFunctions, \
for use in palette buttons.\
\>", "Text"],

Cell[StyleData["Paste"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, After]}]&)}],

Cell[StyleData["Evaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["EvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionMove[ 
        FrontEnd`InputNotebook[ ], All, Cell, 1], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}]
}, Closed]],

Cell[CellGroupData[{

Cell["Placeholder Styles", "Subsection"],

Cell["\<\
The cells below define styles useful for making placeholder objects \
in palette templates.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Placeholder"],
  Editable->False,
  Selectable->False,
  StyleBoxAutoDelete->True,
  Placeholder->True,
  StyleMenuListing->None],

Cell[StyleData["Placeholder", "Printout"]],

Cell[StyleData["Placeholder", "EnhancedPrintout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SelectionPlaceholder"],
  Editable->False,
  Selectable->False,
  StyleBoxAutoDelete->True,
  Placeholder->PrimaryPlaceholder,
  StyleMenuListing->None,
  DrawHighlighted->True],

Cell[StyleData["SelectionPlaceholder", "Printout"]],

Cell[StyleData["SelectionPlaceholder", "EnhancedPrintout"]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FormatType Styles", "Subsection"],

Cell["\<\
The cells below define styles that are mixed in with the styles of \
most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["CellExpression"],
  PageWidth->WindowWidth,
  CellMargins->{{6, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  ShowSpecialCharacters->False,
  AllowInlineCells->False,
  AutoItalicWords->{},
  StyleMenuListing->None,
  FontFamily->"Courier",
  Background->GrayLevel[1]],

Cell[StyleData["CellExpression", "Printout"],
  FontSize->12,
  PrivateFontOptions->{"FontType"->"Bitmap"}]
}, Closed]],

Cell[StyleData["InputForm"],
  AllowInlineCells->False,
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["OutputForm"],
  PageWidth->Infinity,
  TextAlignment->Left,
  LineSpacing->{1, -5},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["StandardForm"],
  LineSpacing->{1.25, 0},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["TraditionalForm"],
  LineSpacing->{1.25, 0},
  SingleLetterItalics->True,
  TraditionalFunctionNotation->True,
  DelimiterMatching->None,
  StyleMenuListing->None],

Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],

Cell[StyleData["InlineCell"],
  TextAlignment->Left,
  ScriptLevel->1,
  StyleMenuListing->None],

Cell[StyleData["InlineCellEditing"],
  StyleMenuListing->None,
  Background->RGBColor[1, 0.749996, 0.8]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["User Defined", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Custom1"]],

Cell[StyleData["Custom1", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Custom2"]],

Cell[StyleData["Custom2", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Custom3"]],

Cell[StyleData["Custom3", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
ScreenStyleEnvironment->"Working",
WindowToolbars->"RulerBar",
WindowSize->{507, 532},
WindowMargins->{{188, Automatic}, {6, Automatic}},
Magnification->1,
StyleDefinitions -> "Default.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 48, 0, 64, "Subtitle"],
Cell[1790, 53, 193, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[2008, 61, 42, 0, 54, "Section"],
Cell[2053, 63, 77, 2, 38, 31, 0, "StyleData", "All", "Working"],
Cell[2133, 67, 140, 4, 33, 32, 0, "StyleData", "All", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[2310, 76, 35, 0, 34, "Section"],
Cell[2348, 78, 101, 3, 32, "Text"],
Cell[2452, 83, 511, 15, 38, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[3000, 103, 41, 0, 34, "Section"],

Cell[CellGroupData[{
Cell[3066, 107, 351, 9, 118, 24, 0, "StyleData", "Title", "All",
  CounterIncrements->"Title",
  CounterAssignments->{{"Chapter", 0}, {"Section", 0}, {"Equation", 0}, {
      "Figure", 0}, {"Subtitle", 0}, {"Example", 0}}],
Cell[3420, 118, 52, 1, 107, 36, 0, "StyleData", "Title", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[3509, 124, 379, 10, 73, 27, 0, "StyleData", "Subtitle", "All",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}}],
Cell[3891, 136, 82, 2, 70, 39, 0, "StyleData", "Subtitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4010, 143, 409, 9, 146, 26, 0, "StyleData", "Chapter", "All",
  CounterIncrements->"Chapter",
  CounterAssignments->{{"Section", 0}, {"Theorem", 0}, {"InferenceRule", 0}, {
      "Definition", 0}, {"Equation", 0}, {"Figure", 0}, {"Example", 0}}],
Cell[4422, 154, 140, 4, 162, 38, 0, "StyleData", "Chapter", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4599, 163, 319, 9, 66, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[4921, 174, 89, 2, 60, 38, 0, "StyleData", "Section", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[5047, 181, 306, 9, 59, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[5356, 192, 91, 2, 55, 41, 0, "StyleData", "Subsection", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[5484, 199, 266, 8, 56, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection"],
Cell[5753, 209, 94, 2, 48, 44, 0, "StyleData", "Subsubsection", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5896, 217, 49, 0, 34, "Section"],
Cell[5948, 219, 225, 4, 68, "Text"],

Cell[CellGroupData[{
Cell[6198, 227, 360, 8, 44, 35, 0, "StyleData", "NumberedEquation", "All",
  CounterIncrements->"NumberedEquation"],
Cell[6561, 237, 82, 1, 43, 47, 0, "StyleData", "NumberedEquation", \
"Printout"],
Cell[6646, 240, 133, 3, 38, 55, 0, "StyleData", "NumberedEquation", \
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6828, 249, 28, 0, 34, "Section"],

Cell[CellGroupData[{
Cell[6881, 253, 157, 5, 44, 23, 0, "StyleData", "Text", "All",
  CounterIncrements->"Text"],
Cell[7041, 260, 68, 1, 42, 35, 0, "StyleData", "Text", "Printout"],
Cell[7112, 263, 118, 3, 40, 43, 0, "StyleData", "Text", "EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7267, 271, 188, 6, 39, 28, 0, "StyleData", "SmallText", "All",
  CounterIncrements->"SmallText",
  StyleMenuListing->None],
Cell[7458, 279, 88, 2, 70, 40, 0, "StyleData", "SmallText", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7595, 287, 42, 0, 34, "Section"],
Cell[7640, 289, 264, 6, 62, "Text"],

Cell[CellGroupData[{
Cell[7929, 299, 776, 24, 46, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input"],
Cell[8708, 325, 137, 4, 54, 36, 0, "StyleData", "Input", "Printout"],
Cell[8848, 331, 106, 2, 55, 44, 0, "StyleData", "Input", "EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[8991, 338, 624, 17, 61, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output"],
Cell[9618, 357, 143, 4, 54, 37, 0, "StyleData", "Output", "Printout"],
Cell[9764, 363, 107, 2, 55, 45, 0, "StyleData", "Output", "EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9908, 370, 540, 16, 36, 26, 0, "StyleData", "Message", "All",
  CounterIncrements->"Message",
  StyleMenuListing->None],
Cell[10451, 388, 123, 2, 70, 38, 0, "StyleData", "Message", "Printout"],
Cell[10577, 392, 159, 3, 70, 46, 0, "StyleData", "Message", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[10773, 400, 514, 15, 36, 24, 0, "StyleData", "Print", "All",
  CounterIncrements->"Print",
  StyleMenuListing->None],
Cell[11290, 417, 94, 1, 70, 36, 0, "StyleData", "Print", "Printout"],
Cell[11387, 420, 130, 2, 70, 44, 0, "StyleData", "Print", "EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[11554, 427, 405, 12, 36, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics",
  StyleMenuListing->None],
Cell[11962, 441, 122, 2, 70, 39, 0, "StyleData", "Graphics", "Printout"],
Cell[12087, 445, 158, 3, 70, 47, 0, "StyleData", "Graphics", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[12282, 453, 129, 4, 36, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[12414, 459, 115, 3, 70, 40, 0, "StyleData", "CellLabel", "Printout"],
Cell[12532, 464, 126, 3, 70, 48, 0, "StyleData", "CellLabel", \
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[12707, 473, 66, 1, 34, "Section"],

Cell[CellGroupData[{
Cell[12798, 478, 146, 4, 44, 29, 0, "StyleData", "Definition", "All",
  CounterIncrements->"Definition"],
Cell[12947, 484, 74, 1, 70, 41, 0, "StyleData", "Definition", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[13058, 490, 136, 4, 41, 24, 0, "StyleData", "Lemma", "All",
  CounterIncrements->"Lemma"],
Cell[13197, 496, 69, 1, 70, 36, 0, "StyleData", "Lemma", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[13303, 502, 140, 4, 41, 26, 0, "StyleData", "Theorem", "All",
  CounterIncrements->"Theorem"],
Cell[13446, 508, 71, 1, 70, 38, 0, "StyleData", "Theorem", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[13554, 514, 152, 4, 41, 32, 0, "StyleData", "InferenceRule", "All",
  CounterIncrements->"InferenceRule"],
Cell[13709, 520, 78, 1, 46, 44, 0, "StyleData", "InferenceRule", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[13824, 526, 111, 3, 44, 29, 0, "StyleData", "ProofBegin", "All"],
Cell[13938, 531, 74, 1, 42, 41, 0, "StyleData", "ProofBegin", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[14049, 537, 140, 4, 44, 26, 0, "StyleData", "Example", "All",
  CounterIncrements->"Example"],
Cell[14192, 543, 72, 1, 46, 38, 0, "StyleData", "Example", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[14301, 549, 181, 6, 29, 25, 0, "StyleData", "Figure", "All",
  CounterIncrements->"Figure"],
Cell[14485, 557, 86, 2, 31, 37, 0, "StyleData", "Figure", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[14608, 564, 138, 4, 44, 25, 0, "StyleData", "Remark", "All",
  CounterIncrements->"Remark"],
Cell[14749, 570, 71, 1, 46, 37, 0, "StyleData", "Remark", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[14857, 576, 145, 4, 51, 28, 0, "StyleData", "Paragraph", "All",
  CounterIncrements->"Paragraph"],
Cell[15005, 582, 74, 1, 48, 40, 0, "StyleData", "Paragraph", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[15128, 589, 39, 0, 34, "Section"],

Cell[CellGroupData[{
Cell[15192, 593, 190, 5, 44, 30, 0, "StyleData", "MathCaption", "All"],
Cell[15385, 600, 105, 2, 70, 42, 0, "StyleData", "MathCaption", "Printout"],
Cell[15493, 604, 155, 4, 70, 50, 0, "StyleData", "MathCaption", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[15685, 613, 231, 7, 41, 29, 0, "StyleData", "Commentary", "All"],
Cell[15919, 622, 91, 2, 70, 41, 0, "StyleData", "Commentary", "Printout"],
Cell[16013, 626, 125, 3, 70, 49, 0, "StyleData", "Commentary", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[16175, 634, 202, 6, 34, 31, 0, "StyleData", "ItemizedText", "All",
  CounterIncrements->"ItemizedText"],
Cell[16380, 642, 100, 2, 70, 43, 0, "StyleData", "ItemizedText", "Printout"],
Cell[16483, 646, 117, 3, 70, 51, 0, "StyleData", "ItemizedText", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[16637, 654, 204, 6, 34, 32, 0, "StyleData", "ItemizedText1", "All",
  CounterIncrements->"ItemizedText1"],
Cell[16844, 662, 101, 2, 70, 44, 0, "StyleData", "ItemizedText1", \
"Printout"],
Cell[16948, 666, 118, 3, 70, 52, 0, "StyleData", "ItemizedText1", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[17103, 674, 162, 4, 34, 35, 0, "StyleData", "ItemizedTextNote", "All",
  CounterIncrements->"Text"],
Cell[17268, 680, 105, 1, 70, 47, 0, "StyleData", "ItemizedTextNote", \
"Printout"],
Cell[17376, 683, 155, 3, 70, 55, 0, "StyleData", "ItemizedTextNote", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[17568, 691, 163, 5, 34, 29, 0, "StyleData", "BulletText", "All"],
Cell[17734, 698, 98, 2, 70, 41, 0, "StyleData", "BulletText", "Printout"],
Cell[17835, 702, 115, 3, 70, 49, 0, "StyleData", "BulletText", \
"EnhancedPrintout"],
Cell[17953, 707, 122, 3, 70, 56, 0, "StyleData", "BulletText", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[18112, 715, 164, 5, 34, 30, 0, "StyleData", "BulletText1", "All"],
Cell[18279, 722, 99, 2, 70, 42, 0, "StyleData", "BulletText1", "Printout"],
Cell[18381, 726, 116, 3, 70, 50, 0, "StyleData", "BulletText1", \
"EnhancedPrintout"],
Cell[18500, 731, 123, 3, 70, 57, 0, "StyleData", "BulletText1", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[18660, 739, 197, 6, 34, 25, 0, "StyleData", "BItem1", "All"],
Cell[18860, 747, 73, 1, 34, 37, 0, "StyleData", "BItem1", "Printout"],
Cell[18936, 750, 111, 3, 32, 45, 0, "StyleData", "BItem1", \
"EnhancedPrintout"],
Cell[19050, 755, 118, 3, 32, 52, 0, "StyleData", "BItem1", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[19205, 763, 349, 10, 34, 25, 0, "StyleData", "NItem1", "All",
  CounterIncrements->"NItem1"],
Cell[19557, 775, 71, 1, 70, 37, 0, "StyleData", "NItem1", "Printout"],
Cell[19631, 778, 111, 3, 70, 45, 0, "StyleData", "NItem1", \
"EnhancedPrintout"],
Cell[19745, 783, 118, 3, 70, 52, 0, "StyleData", "NItem1", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[19900, 791, 166, 5, 38, 33, 0, "StyleData", "ContinueBItem1", "All"],
Cell[20069, 798, 81, 1, 34, 45, 0, "StyleData", "ContinueBItem1", \
"Printout"],
Cell[20153, 801, 119, 3, 32, 53, 0, "StyleData", "ContinueBItem1", \
"EnhancedPrintout"],
Cell[20275, 806, 126, 3, 32, 60, 0, "StyleData", "ContinueBItem1", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[20438, 814, 197, 6, 34, 25, 0, "StyleData", "BItem2", "All"],
Cell[20638, 822, 74, 1, 34, 37, 0, "StyleData", "BItem2", "Printout"],
Cell[20715, 825, 111, 3, 32, 45, 0, "StyleData", "BItem2", \
"EnhancedPrintout"],
Cell[20829, 830, 118, 3, 32, 52, 0, "StyleData", "BItem2", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[20984, 838, 345, 10, 34, 25, 0, "StyleData", "NItem2", "All",
  CounterIncrements->"NItem2"],
Cell[21332, 850, 71, 1, 70, 37, 0, "StyleData", "NItem2", "Printout"],
Cell[21406, 853, 111, 3, 70, 45, 0, "StyleData", "NItem2", \
"EnhancedPrintout"],
Cell[21520, 858, 118, 3, 70, 52, 0, "StyleData", "NItem2", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[21675, 866, 159, 4, 34, 31, 0, "StyleData", "IndentedText", "All",
  CounterIncrements->"Text"],
Cell[21837, 872, 43, 0, 70, 43, 0, "StyleData", "IndentedText", "Printout"],
Cell[21883, 874, 93, 2, 70, 51, 0, "StyleData", "IndentedText", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22013, 881, 101, 2, 34, 26, 0, "StyleData", "Picture", "All"],
Cell[22117, 885, 79, 1, 70, 38, 0, "StyleData", "Picture", "Printout"],
Cell[22199, 888, 87, 1, 70, 46, 0, "StyleData", "Picture", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22323, 894, 128, 4, 33, 26, 0, "StyleData", "Caption", "All"],
Cell[22454, 900, 88, 2, 70, 38, 0, "StyleData", "Caption", "Printout"],
Cell[22545, 904, 120, 3, 70, 46, 0, "StyleData", "Caption", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22702, 912, 144, 4, 41, 28, 0, "StyleData", "Reference", "All",
  CounterIncrements->"Reference"],
Cell[22849, 918, 73, 1, 42, 40, 0, "StyleData", "Reference", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[22971, 925, 43, 0, 34, "Section"],

Cell[CellGroupData[{
Cell[23039, 929, 230, 6, 44, 33, 0, "StyleData", "DisplayFormula", "All",
  StyleMenuListing->None],
Cell[23272, 937, 80, 1, 43, 45, 0, "StyleData", "DisplayFormula", \
"Printout"],
Cell[23355, 940, 79, 1, 44, 53, 0, "StyleData", "DisplayFormula", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[23471, 946, 172, 4, 51, 26, 0, "StyleData", "Program", "All"],
Cell[23646, 952, 81, 1, 51, 38, 0, "StyleData", "Program", "Printout"],
Cell[23730, 955, 134, 3, 47, 46, 0, "StyleData", "Program", \
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[23913, 964, 24, 0, 34, "Section"],

Cell[CellGroupData[{
Cell[23962, 968, 84, 2, 55, 32, 0, "StyleData", "DefinitionBox", "All"],
Cell[24049, 972, 93, 2, 70, 44, 0, "StyleData", "DefinitionBox", "Printout"],
Cell[24145, 976, 127, 3, 70, 52, 0, "StyleData", "DefinitionBox", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[24309, 984, 267, 9, 53, 26, 0, "StyleData", "GrayBox", "All"],
Cell[24579, 995, 122, 3, 70, 38, 0, "StyleData", "GrayBox", "Printout"],
Cell[24704, 1000, 130, 3, 70, 46, 0, "StyleData", "GrayBox", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[24871, 1008, 261, 9, 36, 24, 0, "StyleData", "Table", "All"],
Cell[25135, 1019, 85, 2, 70, 36, 0, "StyleData", "Table", "Printout"],
Cell[25223, 1023, 93, 2, 70, 44, 0, "StyleData", "Table", "EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[25353, 1030, 409, 15, 36, 32, 0, "StyleData", "2ColumnTable1", "All"],
Cell[25765, 1047, 93, 2, 38, 44, 0, "StyleData", "2ColumnTable1", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[25895, 1054, 370, 14, 40, 31, 0, "StyleData", "2ColumnTable", "All"],
Cell[26268, 1070, 92, 2, 38, 43, 0, "StyleData", "2ColumnTable", "Printout"],
Cell[26363, 1074, 100, 2, 36, 51, 0, "StyleData", "2ColumnTable", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[26500, 1081, 408, 15, 40, 31, 0, "StyleData", "3ColumnTable", "All"],
Cell[26911, 1098, 92, 2, 38, 43, 0, "StyleData", "3ColumnTable", "Printout"],
Cell[27006, 1102, 100, 2, 36, 51, 0, "StyleData", "3ColumnTable", \
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[27155, 1110, 57, 1, 26, "Section"],

Cell[CellGroupData[{
Cell[27237, 1115, 203, 6, 45, 24, 0, "StyleData", "Label", "All",
  StyleMenuListing->None],
Cell[27443, 1123, 112, 3, 41, 36, 0, "StyleData", "Label", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[27592, 1131, 208, 6, 45, 29, 0, "StyleData", "Conclusion", "All",
  StyleMenuListing->None],
Cell[27803, 1139, 117, 3, 41, 41, 0, "StyleData", "Conclusion", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[27957, 1147, 231, 7, 45, 29, 0, "StyleData", "Assumption", "All",
  StyleMenuListing->None],
Cell[28191, 1156, 117, 3, 41, 41, 0, "StyleData", "Assumption", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[28345, 1164, 232, 6, 45, 29, 0, "StyleData", "Expression", "All",
  StyleMenuListing->None],
Cell[28580, 1172, 92, 2, 41, 41, 0, "StyleData", "Expression", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[28709, 1179, 228, 6, 44, 26, 0, "StyleData", "TmaText", "All",
  StyleMenuListing->None],
Cell[28940, 1187, 88, 2, 40, 38, 0, "StyleData", "TmaText", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[29065, 1194, 119, 4, 36, 25, 0, "StyleData", "Indent", "All",
  StyleMenuListing->None],
Cell[29187, 1200, 66, 1, 36, 37, 0, "StyleData", "Indent", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[29290, 1206, 118, 4, 36, 24, 0, "StyleData", "Blank", "All",
  StyleMenuListing->None],
Cell[29411, 1212, 65, 1, 38, 36, 0, "StyleData", "Blank", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[29525, 1219, 36, 0, 34, "Section"],
Cell[29564, 1221, 121, 3, 50, "Text"],
Cell[29688, 1226, 92, 3, 38, 21, 0, "StyleData", "RM", "All",
  StyleMenuListing->None],
Cell[29783, 1231, 91, 3, 38, 21, 0, "StyleData", "BF", "All",
  StyleMenuListing->None],
Cell[29877, 1236, 93, 3, 38, 21, 0, "StyleData", "IT", "All",
  StyleMenuListing->None],
Cell[29973, 1241, 92, 3, 38, 21, 0, "StyleData", "BI", "All",
  StyleMenuListing->None],
Cell[30068, 1246, 115, 4, 38, 21, 0, "StyleData", "TR", "All",
  StyleMenuListing->None],
Cell[30186, 1252, 116, 4, 38, 21, 0, "StyleData", "TI", "All",
  StyleMenuListing->None],
Cell[30305, 1258, 114, 4, 38, 21, 0, "StyleData", "TB", "All",
  StyleMenuListing->None],
Cell[30422, 1264, 116, 4, 38, 22, 0, "StyleData", "TBI", "All",
  StyleMenuListing->None],
Cell[30541, 1270, 117, 4, 37, 21, 0, "StyleData", "MR", "All",
  StyleMenuListing->None],
Cell[30661, 1276, 118, 4, 38, 21, 0, "StyleData", "MO", "All",
  StyleMenuListing->None],
Cell[30782, 1282, 116, 4, 37, 21, 0, "StyleData", "MB", "All",
  StyleMenuListing->None],
Cell[30901, 1288, 118, 4, 38, 22, 0, "StyleData", "MBO", "All",
  StyleMenuListing->None],
Cell[31022, 1294, 115, 4, 38, 21, 0, "StyleData", "SR", "All",
  StyleMenuListing->None],
Cell[31140, 1300, 120, 4, 38, 21, 0, "StyleData", "SO", "All",
  StyleMenuListing->None],
Cell[31263, 1306, 118, 4, 38, 21, 0, "StyleData", "SB", "All",
  StyleMenuListing->None],
Cell[31384, 1312, 120, 4, 38, 22, 0, "StyleData", "SBO", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[31541, 1321, 37, 0, 34, "Section"],

Cell[CellGroupData[{
Cell[31603, 1325, 184, 6, 70, 32, 0, "StyleData", "ContentsTitle", "All",
  StyleMenuListing->None],
Cell[31790, 1333, 119, 3, 70, 44, 0, "StyleData", "ContentsTitle", \
"Printout"],
Cell[31912, 1338, 151, 4, 70, 52, 0, "StyleData", "ContentsTitle", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[32100, 1347, 186, 6, 70, 34, 0, "StyleData", "ContentsChapter", "All",
  StyleMenuListing->None],
Cell[32289, 1355, 121, 3, 70, 46, 0, "StyleData", "ContentsSection", \
"Printout"],
Cell[32413, 1360, 153, 4, 70, 54, 0, "StyleData", "ContentsSection", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[32603, 1369, 186, 6, 70, 34, 0, "StyleData", "ContentsSection", "All",
  StyleMenuListing->None],
Cell[32792, 1377, 121, 3, 70, 46, 0, "StyleData", "ContentsSection", \
"Printout"],
Cell[32916, 1382, 153, 4, 70, 54, 0, "StyleData", "ContentsSection", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[33106, 1391, 113, 3, 70, 27, 0, "StyleData", "Contents", "All",
  StyleMenuListing->None],
Cell[33222, 1396, 72, 1, 70, 39, 0, "StyleData", "Contents", "Printout"],
Cell[33297, 1399, 122, 3, 70, 47, 0, "StyleData", "Contents", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[33456, 1407, 134, 4, 70, 24, 0, "StyleData", "Index", "All",
  StyleMenuListing->None],
Cell[33593, 1413, 86, 2, 70, 36, 0, "StyleData", "Index", "Printout"],
Cell[33682, 1417, 120, 3, 70, 44, 0, "StyleData", "Index", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[33839, 1425, 142, 4, 70, 32, 0, "StyleData", "IndexSubentry", "All",
  StyleMenuListing->None],
Cell[33984, 1431, 94, 2, 70, 44, 0, "StyleData", "IndexSubentry", \
"Printout"],
Cell[34081, 1435, 128, 3, 70, 52, 0, "StyleData", "IndexSubentry", \
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[34258, 1444, 49, 0, 34, "Section"],
Cell[34310, 1446, 158, 5, 33, 37, 0, "StyleData", "Header", "Printout",
  StyleMenuListing->None],
Cell[34471, 1453, 169, 5, 33, 45, 0, "StyleData", "Header", \
"EnhancedPrintout",
  StyleMenuListing->None],
Cell[34643, 1460, 160, 5, 29, 37, 0, "StyleData", "Footer", "Printout",
  StyleMenuListing->None],
Cell[34806, 1467, 165, 5, 30, 45, 0, "StyleData", "Footer", \
"EnhancedPrintout",
  StyleMenuListing->None],
Cell[34974, 1474, 156, 5, 33, 41, 0, "StyleData", "PageNumber", "Printout",
  StyleMenuListing->None],
Cell[35133, 1481, 170, 5, 33, 49, 0, "StyleData", "PageNumber", \
"EnhancedPrintout",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[35340, 1491, 35, 0, 34, "Section"],
Cell[35378, 1493, 184, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[35587, 1501, 303, 8, 70, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[35893, 1511, 123, 3, 70, 40, 0, "StyleData", "Hyperlink", "Printout"],
Cell[36019, 1516, 157, 4, 70, 48, 0, "StyleData", "Hyperlink", \
"EnhancedPrintout"]
}, Closed]],
Cell[36191, 1523, 104, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[36320, 1530, 316, 8, 70, 31, 0, "StyleData", "MainBookLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[36639, 1540, 126, 3, 70, 43, 0, "StyleData", "MainBookLink", \
"Printout"],
Cell[36768, 1545, 160, 4, 70, 51, 0, "StyleData", "MainBookLink", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[36965, 1554, 337, 9, 70, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[37305, 1565, 148, 4, 70, 40, 0, "StyleData", "AddOnLink", "Printout"],
Cell[37456, 1571, 159, 4, 70, 48, 0, "StyleData", "AddOnLink", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[37652, 1580, 345, 9, 70, 31, 0, "StyleData", "RefGuideLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[38000, 1591, 126, 3, 70, 43, 0, "StyleData", "RefGuideLink", \
"Printout"],
Cell[38129, 1596, 162, 4, 70, 51, 0, "StyleData", "RefGuideLink", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[38328, 1605, 328, 8, 70, 37, 0, "StyleData", "GettingStartedLink", "All",
  
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[38659, 1615, 132, 3, 70, 49, 0, "StyleData", "GettingStartedLink", \
"Printout"],
Cell[38794, 1620, 166, 4, 70, 57, 0, "StyleData", "GettingStartedLink", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[38997, 1629, 332, 8, 70, 39, 0, "StyleData", "OtherInformationLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[39332, 1639, 134, 3, 70, 51, 0, "StyleData", "OtherInformationLink", \
"Printout"],
Cell[39469, 1644, 168, 4, 70, 59, 0, "StyleData", "OtherInformationLink", \
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[39686, 1654, 32, 0, 34, "Section"],

Cell[CellGroupData[{
Cell[39743, 1658, 36, 0, 70, "Subsection"],
Cell[39782, 1660, 121, 3, 70, "Text"],
Cell[39906, 1665, 226, 5, 70, 24, 0, "StyleData", "Paste", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[40135, 1672, 295, 7, 70, 27, 0, "StyleData", "Evaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[40433, 1681, 400, 9, 70, 31, 0, "StyleData", "EvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[40836, 1692, 387, 9, 70, 31, 0, "StyleData", "CopyEvaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[41226, 1703, 401, 9, 70, 35, 0, "StyleData", "CopyEvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[41664, 1717, 40, 0, 70, "Subsection"],
Cell[41707, 1719, 115, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[41847, 1726, 145, 5, 70, 30, 0, "StyleData", "Placeholder", "All",
  StyleMenuListing->None],
Cell[41995, 1733, 42, 0, 70, 42, 0, "StyleData", "Placeholder", "Printout"],
Cell[42040, 1735, 50, 0, 70, 50, 0, "StyleData", "Placeholder", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[42127, 1740, 193, 6, 70, 39, 0, "StyleData", "SelectionPlaceholder", \
"All",
  StyleMenuListing->None],
Cell[42323, 1748, 51, 0, 70, 51, 0, "StyleData", "SelectionPlaceholder", \
"Printout"],
Cell[42377, 1750, 59, 0, 70, 59, 0, "StyleData", "SelectionPlaceholder", \
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[42485, 1756, 39, 0, 70, "Subsection"],
Cell[42527, 1758, 258, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[42810, 1767, 301, 9, 70, 33, 0, "StyleData", "CellExpression", "All",
  StyleMenuListing->None],
Cell[43114, 1778, 107, 2, 70, 45, 0, "StyleData", "CellExpression", \
"Printout"]
}, Closed]],
Cell[43236, 1783, 106, 3, 70, 28, 0, "StyleData", "InputForm", "All",
  StyleMenuListing->None],
Cell[43345, 1788, 150, 5, 70, 29, 0, "StyleData", "OutputForm", "All",
  StyleMenuListing->None],
Cell[43498, 1795, 108, 3, 70, 31, 0, "StyleData", "StandardForm", "All",
  StyleMenuListing->None],
Cell[43609, 1800, 179, 5, 70, 34, 0, "StyleData", "TraditionalForm", "All",
  StyleMenuListing->None],
Cell[43791, 1807, 115, 3, 70, "Text"],
Cell[43909, 1812, 96, 3, 70, 29, 0, "StyleData", "InlineCell", "All",
  StyleMenuListing->None],
Cell[44008, 1817, 104, 2, 70, 36, 0, "StyleData", "InlineCellEditing", "All",
  StyleMenuListing->None]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[44161, 1825, 31, 0, 34, "Section"],

Cell[CellGroupData[{
Cell[44217, 1829, 26, 0, 70, 26, 0, "StyleData", "Custom1", "All"],
Cell[44246, 1831, 71, 1, 70, 38, 0, "StyleData", "Custom1", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[44354, 1837, 26, 0, 70, 26, 0, "StyleData", "Custom2", "All"],
Cell[44383, 1839, 71, 1, 70, 38, 0, "StyleData", "Custom2", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[44491, 1845, 26, 0, 70, 26, 0, "StyleData", "Custom3", "All"],
Cell[44520, 1847, 71, 1, 70, 38, 0, "StyleData", "Custom3", "Printout"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

